import io.github.cdimascio.dotenv.Dotenv
import io.github.cdimascio.dotenv.DotenvException
import io.github.cdimascio.dotenv.dotenv

val dotenv: Dotenv? by lazy {
    try {
        dotenv {
            filename = System.getenv("ENV_NAME") ?: ".env"
        }
    } catch (e: DotenvException) {
        null
    }
}

private fun getEnv(name: String): String? {
    return System.getenv(name) ?: if (dotenv != null) dotenv!![name] else null
}

class Settings {
    companion object {
        val KEYCLOAK_BASE_URL: String = getEnv("KEYCLOAK_BASE_URL") ?: "http://localhost:8180/auth"
        val KEYCLOAK_PRIVATE_BASE_URL = getEnv("KEYCLOAK_PRIVATE_BASE_URL") ?: KEYCLOAK_BASE_URL
        val KEYCLOAK_REALM_NAME = getEnv("KEYCLOAK_REALM_NAME") ?: "harbor"
        val KEYCLOAK_CLIENT_ID: String = getEnv("KEYCLOAK_CLIENT_ID") ?: "backend-api"
        val KEYCLOAK_CLIENT_SECRET: String = getEnv("KEYCLOAK_CLIENT_SECRET") ?: ""
    }
}
